@@ -6,7 +6,14 @@ module DelayedJob
     # since ActiveRecord 3.0
     def next_migration_number(dirname)
       next_migration_number = current_migration_number(dirname) + 1
-      if ActiveRecord::Base.timestamped_migrations
+      timestamped_migrations =
+        if ActiveRecord.respond_to?(:timestamped_migrations)
+          ActiveRecord.timestamped_migrations
+        else
+          ActiveRecord::Base.timestamped_migrations
+        end
+
+      if timestamped_migrations
         [Time.now.utc.strftime("%Y%m%d%H%M%S"), format("%.14d", next_migration_number)].max
       else
         format("%.3d", next_migration_number)
